@@ -8,7 +8,7 @@ function (x, loops = FALSE)
     sep <- ", "
     lb2lb <- TRUE
     ifelse(isTRUE(is.null(dimnames(x)[1]) == TRUE | is.null(dimnames(x)[1][[1]]) == 
-        TRUE) == TRUE, LBS <- 1:nrow(x), LBS <- dimnames(x)[[1]])
+        TRUE) == TRUE, LBS <- seq_len(nrow(x)), LBS <- dimnames(x)[[1]])
     lbs <- seq(LBS)
     xd <- dichot(x, c = 1L, diag.incl = TRUE)
     ifelse(isTRUE(dim(xd)[3] == 1) == TRUE, xd <- xd[, , 1], 
@@ -18,27 +18,27 @@ function (x, loops = FALSE)
         r <- dim(x)[3]
         if (isTRUE(is.null(dimnames(x)[[3]]) == TRUE) | isTRUE(any(duplicated(dimnames(x)[[3]]))) == 
             TRUE) {
-            dimnames(x)[[3]] <- 1:dim(x)[3]
+            dimnames(x)[[3]] <- seq_len(dim(x)[3])
         }
         mlt <- list()
-        for (i in 1:dim(x)[3]) {
-            mlt[[i]] <- transf(xd[, , i], type = "tolist", labels = lbs, 
-                sep = sep, lb2lb = lb2lb)
+        for (i in seq_len(dim(x)[3])) {
+            mlt[[i]] <- trnf(xd[, , i], tolist = TRUE, lbs = lbs, 
+                lb2lb = lb2lb, sep = sep)
         }
         rm(i)
         m <- unlist(mlt)
     }
     else {
         TRD <- FALSE
-        r <- 1
-        m <- transf(xd, type = "tolist", labels = lbs, sep = sep, 
-            lb2lb = lb2lb)
+        r <- 1L
+        m <- trnf(xd, tolist = TRUE, lbs = lbs, lb2lb = lb2lb, 
+            sep = sep)
     }
     bd <- bnd(x, xd, lbs, TRD, r, m, mlt, sep)
     Et <- vector()
     if (isTRUE(TRD == TRUE) == TRUE) {
-        for (i in 1:length(bd$Eout)) {
-            for (j in 1:length(bd$Eout[[i]])) {
+        for (i in seq_len(length(bd$Eout))) {
+            for (j in seq_len(length(bd$Eout[[i]]))) {
                 if (isTRUE(length(bd$Eout[[i]]) != 0L) == TRUE) {
                   Et <- append(Et, paste(lbs[i], bd$Eout[[i]][j], 
                     sep = sep))
@@ -48,10 +48,10 @@ function (x, loops = FALSE)
         }
         rm(i)
         ENT <- list()
-        for (k in 1:r) {
+        for (k in seq_len(r)) {
             tmp <- vector()
-            for (i in which(Et %in% transf(xd[, , k], labels = lbs, 
-                sep = sep, lb2lb = lb2lb))) {
+            for (i in which(Et %in% trnf(xd[, , k], tolist = TRUE, 
+                lbs = lbs, lb2lb = lb2lb, sep = sep))) {
                 tmp <- append(tmp, Et[i])
             }
             rm(i)
@@ -65,7 +65,7 @@ function (x, loops = FALSE)
     if (loops) {
         if (isTRUE(is.na(dim(xd)[3])) == FALSE) {
             vec <- vector()
-            for (i in 1:dim(xd)[3]) {
+            for (i in seq_len(dim(xd)[3])) {
                 vec <- append(vec, sum(diag(xd[, , i])))
             }
             rm(i)
