@@ -1,9 +1,15 @@
 iinc <-
-function (inc, PO, print.eqs = FALSE, sep) 
+function (inc, PO, equat = FALSE, sep) 
 {
     ifelse(missing(sep) == TRUE, sep <- ", ", NA)
-    Pi <- (transf(inc, type = "toarray", ord = dim(PO)[1], sep = sep) + 
-        PO)
+    ifelse(is.null(dimnames(PO)[[1]]) == TRUE, dimnames(PO)[[1]] <- dimnames(PO)[[2]] <- seq(dim(PO)[1]), 
+        NA)
+    lbs <- dimnames(PO)[[1]]
+    INC <- transf(inc, type = "toarray", ord = dim(PO)[1], lb2lb = TRUE, 
+        sep = sep, lbs = lbs)
+    dimnames(INC)[[1]][which(is.na(dimnames(INC)[[1]]))] <- dimnames(INC)[[2]][which(is.na(dimnames(INC)[[1]]))] <- lbs[which(!(lbs %in% 
+        dimnames(INC)[[1]]))]
+    Pi <- mnplx(zbind(INC, PO))
     ls <- list()
     k <- 1
     for (i in 1:(nrow(Pi) - 1)) {
@@ -12,8 +18,8 @@ function (inc, PO, print.eqs = FALSE, sep)
                 if (i != j) {
                   ls[[k]] <- c(i, j)
                   k <- k + 1
-                  if (isTRUE(print.eqs == TRUE) == TRUE) 
-                    print(paste(i, j, sep = " = "))
+                  if (isTRUE(equat == TRUE) == TRUE) 
+                    print(paste(lbs[i], lbs[j], sep = " = "))
                 }
             }
         }
@@ -21,23 +27,23 @@ function (inc, PO, print.eqs = FALSE, sep)
     }
     rm(i)
     if (length(ls) == 0) 
-        return(1:dim(PO)[1])
-    if (sum(transf(inc, type = "toarray", ord = dim(PO)[1]), 
+        return(seq_len(dim(PO)[1]))
+    if (sum(trnf(inc, tolist = FALSE, ord = dim(PO)[1], lb2lb = TRUE), 
         PO) == dim(PO)[1] * dim(PO)[2]) 
         return(rep(1, each = dim(PO)[1]))
-    j <- 1
+    j <- 1L
     attr(ls[[1]], "names")[1] <- attr(ls[[1]], "names")[2] <- j
-    if (length(ls) > 1) {
-        for (i in (j + 1):length(ls)) {
+    if (length(ls) > 1L) {
+        for (i in (j + 1L):length(ls)) {
             if (any(ls[[i]] %in% ls[[j]]) | any(ls[[j]] %in% 
                 ls[[i]])) 
                 attr(ls[[i]], "names")[1] <- attr(ls[[i]], "names")[2] <- j
         }
         rm(i)
-        for (j in 2:length(ls)) {
+        for (j in seq.int(2, length(ls))) {
             if (isTRUE(is.null(attr(ls[[j]], "names")) == TRUE) == 
                 TRUE) {
-                for (i in 1:(j - 1)) {
+                for (i in seq_len((j - 1L))) {
                   ifelse((any(ls[[i]] %in% ls[[j]]) | any(ls[[j]] %in% 
                     ls[[i]])), attr(ls[[j]], "names")[1] <- attr(ls[[j]], 
                     "names")[2] <- as.integer(attr(ls[[i]], "names")[1]), 
@@ -47,7 +53,7 @@ function (inc, PO, print.eqs = FALSE, sep)
             }
         }
         rm(j)
-        for (j in 2:length(ls)) if (isTRUE(is.null(attr(ls[[j]], 
+        for (j in seq.int(2, length(ls))) if (isTRUE(is.null(attr(ls[[j]], 
             "names")) == TRUE) == TRUE) {
             for (i in j:length(ls)) {
                 if (any(ls[[i]] %in% ls[[j]])) 
@@ -56,9 +62,9 @@ function (inc, PO, print.eqs = FALSE, sep)
             }
             rm(i)
             if (j < length(ls)) {
-                for (k in (j + 1):length(ls)) {
+                for (k in (j + 1L):length(ls)) {
                   if (is.null(attr(ls[[k]], "names")) == TRUE) {
-                    for (i in 1:length(ls)) {
+                    for (i in seq_len(length(ls))) {
                       if (is.null(attr(ls[[i]], "names")) == 
                         FALSE) {
                         if (any(ls[[k]] %in% ls[[i]])) 
@@ -76,7 +82,7 @@ function (inc, PO, print.eqs = FALSE, sep)
         rm(j)
     }
     clu <- vector()
-    for (i in 1:length(ls)) {
+    for (i in seq_len(length(ls))) {
         clu[i] <- as.numeric(attr(ls[[i]], "names")[1])
     }
     rm(i)
@@ -84,19 +90,19 @@ function (inc, PO, print.eqs = FALSE, sep)
     x <- clu
     cls <- vector()
     length(cls) <- length(clu)
-    for (i in 1:f) {
+    for (i in seq_len(f)) {
         cls[which(x == as.numeric(levels(factor(clu)))[i])] <- i
     }
     rm(i)
     nls <- ls
-    for (i in 1:length(nls)) {
+    for (i in seq_len(length(nls))) {
         attr(nls[[i]], "names")[1] <- attr(nls[[i]], "names")[2] <- cls[i]
     }
     rm(i)
     cl <- integer()
     length(cl) <- dim(PO)[1]
-    for (k in 1:f) {
-        for (i in 1:length(nls)) {
+    for (k in seq_len(f)) {
+        for (i in seq_len(length(nls))) {
             if (attr(nls[[i]], "names")[1] == as.character(k)) {
                 cl[nls[[i]][1]] <- k
                 cl[nls[[i]][2]] <- k
@@ -106,7 +112,7 @@ function (inc, PO, print.eqs = FALSE, sep)
     }
     rm(k)
     n <- as.numeric(attr(stats::na.omit(cl), "na.action"))
-    for (i in 1:length(n)) {
+    for (i in seq_len(length(n))) {
         cl[n[i]] <- f + i
     }
     rm(i)
