@@ -2,20 +2,22 @@ zbind <-
 function (...) 
 {
     argl <- list(...)
+    if (isTRUE(length(argl) < 2L) == TRUE) 
+        return(argl)
     ifelse(isTRUE(dim(argl[[1]])[3] > 1) == TRUE, pvt <- argl[[1]][, 
         , 1], pvt <- argl[[1]])
     tmp <- data.frame(matrix(ncol = (dim(pvt)[1] * dim(pvt)[2]), 
         nrow = 0L))
-    for (i in 1:length(argl)) {
+    for (i in seq_len(length(argl))) {
         if (isTRUE(i < length(argl)) == TRUE) {
-            if (all.equal(dim(argl[[i + 1]])[1:2], dim(pvt)[1:2]) != 
+            if (all.equal(dim(argl[[i + 1L]])[1:2], dim(pvt)[1:2]) != 
                 TRUE) 
                 stop("Dimmensions of arrays involved are not equal.")
             pvtlbs <- dimnames(pvt)[[1]]
             if (any(dimnames(argl[[i + 1L]])[[1]] != pvtlbs) == 
                 TRUE && isTRUE(dim(argl[[1]])[1] == dim(argl[[1]])[2]) == 
                 TRUE) {
-                prm <- 1:dim(argl[[1]])[1]
+                prm <- seq(dim(pvt)[1])
                 for (m in which(dimnames(argl[[i + 1L]])[[1]] != 
                   pvtlbs)) {
                   prm[m] <- which(dimnames(argl[[i + 1L]])[[1]][m] == 
@@ -27,7 +29,7 @@ function (...)
             }
         }
         if (isTRUE(dim(argl[[i]])[3] > 1L) == TRUE) {
-            for (j in 1:dim(argl[[i]])[3]) {
+            for (j in seq_len(dim(argl[[i]])[3])) {
                 tmp[(nrow(tmp) + 1L), ] <- as.vector(as.matrix(argl[[i]][, 
                   , j]))
             }
@@ -40,8 +42,8 @@ function (...)
     }
     rm(i)
     arr <- array(dim = c(dim(pvt)[1], dim(pvt)[2], nrow(tmp)))
-    for (i in 1:nrow(tmp)) {
-        arr[, , i][1:(dim(pvt)[1] * dim(pvt)[2])] <- as.numeric(tmp[i, 
+    for (i in seq_len(nrow(tmp))) {
+        arr[, , i][seq_len((dim(pvt)[1] * dim(pvt)[2]))] <- as.numeric(tmp[i, 
             ])
     }
     rm(i)
@@ -53,11 +55,11 @@ function (...)
         NA
     }
     lbs <- vector()
-    for (i in 1:length(argl)) {
+    for (i in seq_len(length(argl))) {
         if (isTRUE(dim(argl[[i]])[3] > 1L) == TRUE) {
             ifelse(is.null(dimnames(argl[[i]])[[3]]) == FALSE, 
                 lbs <- append(lbs, dimnames(argl[[i]])[[3]]), 
-                lbs <- append(lbs, (length(lbs) + 1:dim(argl[[i]])[3])))
+                lbs <- append(lbs, (length(lbs) + 1L:dim(argl[[i]])[3])))
         }
         else if (isTRUE(dim(argl[[i]])[3] > 1L) == FALSE) {
             if (isTRUE(is.na(dim(argl[[i]])[3])) == FALSE) {
