@@ -13,13 +13,6 @@ frt <- data.frame(yellow = c(0,1,0,0,1,0,0,0), green = c(0,0,1,0,0,0,0,1), red =
 rownames(frt) <- c("PinkLady","GrannySmith","GoldenDelicious","RedDelicious","Lemon","Orange","Mandarin","Lime")
 frt
 
-## ----readtable, eval=FALSE----------------------------------------------------------------------------------
-#  read.table(file, header = TRUE,
-#    row.names=c("PinkLady","GrannySmith","GoldenDelicious","RedDelicious","Lemon","Orange","Mandarin","Lime"))
-
-## ----readsrt, eval=FALSE------------------------------------------------------------------------------------
-#  read.srt(file, header = TRUE, attr = TRUE, toarray = FALSE)
-
 ## ----loadmultiplex------------------------------------------------------------------------------------------
 ## Load first the package
 library("multiplex")
@@ -56,47 +49,39 @@ diagram(pogc)
 if( require("Rgraphviz", quietly = TRUE)) {
 diagram.levels(pogcc) }
 
-## ----diaglevelsperm, echo=TRUE------------------------------------------------------------------------------
+## ----diaglevelsperm, echo=TRUE, message=FALSE, warning=FALSE------------------------------------------------
 ## Diagram levels with permutation
 if( require("Rgraphviz", quietly = TRUE)) {
 diagram.levels(pogcc, perm = TRUE) }
 
 ## ----princfltr, echo=TRUE-----------------------------------------------------------------------------------
-## Principal filter of third concept
-fltr(3, pogcc)
-
-## ----princfltrlbs, echo=TRUE--------------------------------------------------------------------------------
-## Principal filter of third concept with labels
+## Principal filter of the third concept 
 fltr(3, pogc)
 
-## ----princfltrlbs2, echo=TRUE, eval=FALSE-------------------------------------------------------------------
-#  fltr("red", pogc)
+## ----princfltrlbs, echo=TRUE, eval=FALSE--------------------------------------------------------------------
+#  ## Principal filter of the concept with these labels
+#  fltr("PinkLady", pogc)
+#  fltr(c("red", "RedDelicious"), pogc)
 
-## ----princideal, echo=TRUE----------------------------------------------------------------------------------
-## Principal ideal of the third concept
-fltr(3, pogc, ideal = TRUE)
+## ----filter, echo=TRUE--------------------------------------------------------------------------------------
+## Filter of two concepts
+fltr(c("Lemon", "Lime"), pogc)
 
-## ----lstfrt, echo=-2----------------------------------------------------------------------------------------
-lstfrt <- transf(frt, type = "matlist", lb2lb = TRUE)
-lstfrt
+## ----ideal, echo=TRUE---------------------------------------------------------------------------------------
+## Ideal of two concepts
+fltr(c(9, 11), pogc, ideal = TRUE)
 
-## ----matlstfrt, echo=TRUE-----------------------------------------------------------------------------------
-mlstfrt <- transf(lstfrt, type = "listmat", lb2lb = TRUE)
+## ----bipp, echo=TRUE, eval=TRUE, fig.pos='H', fig.width=4, fig.height=4, fig.align='center', fig.env='figure', fig.cap='Bipartite graph'----
+## Load the "multigraph" package
+library("multigraph")
 
-## ----setup2, include=FALSE------------------------------------------------------------------------------------------------------
-# smaller font size for chunks
-options(width=130)
+## Plot bipartite graph
+bmgraph(frt, pch = 16:15, tcex = .8)
 
-## ----matlstfrtecho, echo=FALSE, size='scriptsize'-------------------------------------------------------------------------------
-mlstfrt
+## ----binp2, echo=TRUE, eval=FALSE---------------------------------------------------------------------------
+#  ## Plot proyection of bipartite network
+#  bmgraph(frt, layout = "force", seed = 1, cex = 3, tcex = .7, vcol = 8, pch = 16:15)
 
-## ----bipgraph, fig.pos='H', fig.width=4, fig.height=4, fig.align='center', fig.env='figure', fig.cap='Bipartite graph of the fruit characteristics ', small.mar=TRUE----
-if( require("Rgraphviz", quietly = TRUE)) {
-diagram(mlstfrt)
-}
-
-## ----bipgraphB, fig.pos='H', fig.width=4, fig.height=4, fig.align='center', fig.env='figure', fig.cap='Transpose depiction of the Bipartite graph', small.mar=TRUE----
-if( require("Rgraphviz", quietly = TRUE)) {
-diagram(t(mlstfrt)) 
-}
+## ----binp, fig.pos='H', fig.width=5, fig.height=5, fig.align='center', fig.env='figure', fig.cap='Bipartite graph with force-directed layout', echo=FALSE----
+bmgraph(frt, layout = "force", seed = 1, cex = 3, tcex = .7, vcol = 8, pch = 16:15)
 
